@@ -6,8 +6,8 @@ afs='false'
 afsroot='/afs'
 alignbytes='4'
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.23/unknown'
-archlibexp='/usr/local/lib/perl5/5.23/unknown'
+archlib='/usr/local/lib/perl5/5.27/unknown'
+archlibexp='/usr/local/lib/perl5/5.27/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
@@ -107,6 +107,14 @@ d_dlerror='undef'
 d_dlopen='undef'
 d_dlsymun='undef'
 d_dosuid='undef'
+d_double_has_inf='define'
+d_double_has_nan='define'
+d_double_has_negative_zero='define'
+d_double_has_subnormals='define'
+d_double_style_cray='undef'
+d_double_style_ibm='undef'
+d_double_style_ieee='define'
+d_double_style_vax='undef'
 d_drand48_r='undef'
 d_drand48proto='undef'
 d_dup2='undef'
@@ -171,6 +179,7 @@ d_fsync='undef'
 d_ftello='undef'
 d_ftime='undef'
 d_futimes='undef'
+d_gai_strerror='undef'
 d_gdbm_ndbm_h_uses_prototypes='undef'
 d_gdbmndbm_h_uses_prototypes='undef'
 d_getaddrinfo='undef'
@@ -284,6 +293,11 @@ d_lockf='undef'
 d_log1p='undef'
 d_log2='undef'
 d_logb='undef'
+d_long_double_style_ieee='undef'
+d_long_double_style_ieee_doubledouble='undef'
+d_long_double_style_ieee_extended='undef'
+d_long_double_style_ieee_std='undef'
+d_long_double_style_vax='undef'
 d_longdbl='undef'
 d_longlong='undef'
 d_lrint='undef'
@@ -301,6 +315,7 @@ d_mbtowc='undef'
 d_memchr='define'
 d_memcmp='define'
 d_memcpy='define'
+d_memmem='undef'
 d_memmove='undef'
 d_memset='define'
 d_mkdir='undef'
@@ -370,6 +385,7 @@ d_pwpasswd='undef'
 d_pwquota='undef'
 d_qgcvt='undef'
 d_quad='undef'
+d_querylocale='undef'
 d_random_r='undef'
 d_readdir64_r='undef'
 d_readdir='define'
@@ -486,6 +502,7 @@ d_strcoll='undef'
 d_strctcpy='undef'
 d_strerrm='strerror(e)'
 d_strerror='undef'
+d_strerror_l='undef'
 d_strerror_r='undef'
 d_strftime='undef'
 d_strlcat='undef'
@@ -557,6 +574,7 @@ db_prefixtype='size_t'
 db_version_major='0'
 db_version_minor='0'
 db_version_patch='0'
+default_inc_excludes_dot='undef'
 direntrytype='struct dirent'
 doubleinfbytes='0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f'
 doublekind='3'
@@ -709,6 +727,7 @@ i_values='undef'
 i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
+i_xlocale='undef'
 ignore_versioned_solibs='y'
 inc_version_list_init='NULL'
 installstyle='lib/perl5'
@@ -763,8 +782,8 @@ package='perl5'
 perl_static_inline='static'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.23'
-privlibexp='/usr/local/lib/perl5/5.23'
+privlib='/usr/local/lib/perl5/5.27'
+privlibexp='/usr/local/lib/perl5/5.27'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
@@ -814,11 +833,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.23/unknown'
-sitearchexp='/usr/local/lib/perl5/5.23/unknown'
-sitelib='/usr/local/lib/perl5/5.23'
+sitearch='/usr/local/lib/perl5/5.27/unknown'
+sitearchexp='/usr/local/lib/perl5/5.27/unknown'
+sitelib='/usr/local/lib/perl5/5.27'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.23'
+sitelibexp='/usr/local/lib/perl5/5.27'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
